@@ -1,4 +1,4 @@
-# Copyright (c) 2016-2024 Martin Donath <martin.donath@squidfunk.com>
+# Copyright (c) 2016-2025 Martin Donath <martin.donath@squidfunk.com>
 
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to
@@ -215,7 +215,7 @@ class SearchIndex:
             entry["tags"] = []
             for name in tags:
                 if name and isinstance(name, (str, int, float, bool)):
-                    entry["tags"].append(name)
+                    entry["tags"].append(str(name))
 
         # Set document boost
         search = page.meta.get("search") or {}
